@@ -6,7 +6,7 @@ use Mojo::Util 'deprecated';
 use Carp 'croak';
 use strict;
 
-our $VERSION = '1.52';
+our $VERSION = '1.53';
 
 has providers => sub {
   return {
@@ -53,11 +53,6 @@ sub register {
 
   $self->providers($providers);
 
-  unless ($self->{fix_get_token} = $config->{fix_get_token}) {
-    deprecated
-      "\$c->oauth2->get_token(...) has changed api! Please set 'fix_get_token' in the config arguments to move forward. Sorry for the inconvenience.";
-  }
-
   if ($providers->{mocked}{key}) {
     $self->_mock_interface($app);
   }
@@ -222,9 +217,7 @@ sub _process_response_code {
           $data = Mojo::Parameters->new($tx->res->body)->to_hash;
         }
 
-        $err = $data ? '' : $err || 'Unknown error';
-
-        $c->$cb($err, $self->{fix_get_token} ? $data : $data->{access_token});
+        $c->$cb($data ? '' : $err || 'Unknown error', $data);
       },
     );
   }
@@ -288,7 +281,13 @@ sub _mock_interface {
     $provider->{token_url} => sub {
       my $c = shift;
       if ($c->param('client_secret') and $c->param('redirect_uri') and $c->param('code')) {
-        my $qp = Mojo::Parameters->new(access_token => $provider->{return_token}, lifetime => 3600);
+        my $qp = Mojo::Parameters->new(
+          access_token  => $provider->{return_token},
+          expires_in    => 3600,
+          refresh_token => Mojo::Util::md5_sum(rand),
+          scope         => $provider->{scopes} || 'some list of scopes',
+          token_type    => 'bearer',
+        );
         $c->render(text => $qp->to_string);
       }
       else {
@@ -316,6 +315,14 @@ L<IO::Socket::SSL> is installed.
 
    $ mojo version
 
+=head2 Breaking changes
+
+Between 1.51 (2015-03-18) and 1.53 (2015-09-08) we decided to remove the back
+compat hack for L</get_token>, making it act I<only> as documented.
+
+The two helpers C<get_authorize_url()> and C<get_token()> will be removed
+soon. They have been deprecated since 1.4 (2015-03-01).
+
 =head2 References
 
 =over 4
@@ -534,6 +541,7 @@ as a GET parameter called C<state> in the URL that the user will return to.
   $data = $c->oauth2->get_token($provider_name => \%args);
   $c    = $c->oauth2->get_token($provider_name => \%args, sub {
             my ($c, $err, $data) = @_;
+            # do stuff with $data->{access_token} if it exists.
           });
 
 L</oauth2.get_token> is used to either fetch access token from OAuth2 provider,
@@ -559,14 +567,15 @@ connect your site with his/her profile on the OAuth2 provider's page or not.
 
 The OAuth2 provider will redirect the user back to your site after clicking the
 "Connect" or "Reject" button. C<$data> will then contain a key "access_token"
-on "Connect" and a false value on "Reject" mode, or will die in blocking mode.
+on "Connect" and a false value (or die in blocking mode) on "Reject".
 
 =back
 
-Will redirect to the provider to allow for authorization, then fetch the
-token. The token gets provided as a parameter to the callback function.
-Usually you want to store the token in a session or similar to use for
-API requests. Supported arguments:
+The method takes these arguments: C<$provider_name> need to match on of
+the provider names under L</Configuration> or a custom provider defined
+when L<registering|/SYNOPSIS> the plugin.
+
+C<%args> can have:
 
 =over 4
 
